Sutekh Card Set Filters

# Card Set Filters for Sutekh 2.2.1

## Contents

1. Usage
2. Keyboard Navigation
3. Filter Elements
   1. Filter Group
   2. Card Set Marked as in Use
   3. Card Set Annotations
   4. Card Set Author
   5. Card Set Description
   6. Card Set Name
   7. Parent Card Set

## Usage

Filter elements and values for the filters can be dragged from the right hand pane to the filter to add them to the filter, and dragged from the filter to the right hand pane to remove them from the filter. Disabled filter elements or filter elements with no values set are ignored.

## Keyboard Navigation

You can switch between the different filter lists using <Alt>—<Left> and <Alt>—<Right>. <Ctrl>—<Enter> will paste the currently selected list of values into the filter. <Del> will delete a value or filter part from the filter <Ctrl>—<Space> will disable a filter part, while <Alt>—<Space> will negate it.

## Filter Elements

The available filtering options are listed below. The first line of each item shows the description you’ll see in the filter editor in bold. The rest of the description describes the arguments the filter takes and the results it produces.

### Filter Group

Parameters: A list of other filter elements.

Filter element with holds other filter elements. The result of the filter group is the combination of all the filter elements as specified by the Filter Group type.

The 4 Group types are:

- All of: This filter matches only if every filter in the group matches.
- Any of: This filter matches if at least one of the filters in the group matches.
- Not all of: This filter matches if at least one of the filters in the group doesn’t match.
- Not any of: This filter matches only if none of the filters in the group match.

### Card Set Marked as in Use

Parameters: This filter takes no parameters

Selects those Card Sets in the Card Set List that are marked as in use.

### Card Set Annotations

Parameters: the text to be matched against card set annotations. (% and _ can be used as wildcards.)

Returns all card sets where the annotations contain the given string.

### Card Set Author

Parameters: the text to be matched against card set Author. (% and _ can be used as wildcards.)

Returns all card sets whose author includes the given string.

### Card Set Description

Parameters: the text to be matched against card set description. (% and _ can be used as wildcards.)

Returns all card sets containing the given string in the description.

### Card Set Name

Parameters: the text to be matched against card set names. (% and _ can be used as wildcards.)

Returns all card sets whose name contains the given string.

### Parent Card Set

Parameters: a list names of the parent card sets.

Returns all card sets with one of the selected card sets as a parent.